#![forbid(unsafe_code)]

use libdit::libdit::dit_struct_to_unix;
pub use libdit::libdit::unix_to_dit_string;
use libdit::libdit::Dit;
pub use libstardit::libstardit::unix_to_stardit;
use std::env;
use std::process::exit;
use std::str::FromStr;
pub use std::time::{SystemTime, UNIX_EPOCH};

fn main() {
	let args: Vec<String> = env::args().collect();

	match args.len() {
		1 => current(),
		2 => parse(args[1].to_string()),
		_ => {
			eprintln!("Wrong usage");
			exit(1);
		}
	}
}

fn current() {
	let current_timestamp = SystemTime::now()
		.duration_since(UNIX_EPOCH)
		.unwrap()
		.as_secs_f64();

	let stardit = unix_to_stardit(current_timestamp);

	println!(
		"{}\n{}, décade {}, {}",
		unix_to_dit_string(current_timestamp),
		stardit.year,
		stardit.weekade,
		stardit.day_name,
	);
}

fn parse(arg: String) {
	match Dit::from_str(&arg) {
		Ok(dit) => {
			println!("{}", dit_struct_to_unix(dit));
		}
		Err(_) => {
			eprintln!("{} is not a valid DIT!", arg);
			exit(1);
		}
	}
}
